## 8.0.0.0 (2023-01-29)

[stubsabot] Bump python-slugify to 8.0.* (#9602)

Release: https://pypi.org/pypi/python-slugify/8.0.0
Homepage: https://github.com/un33k/python-slugify
Diff: https://github.com/un33k/python-slugify/compare/v7.0.0...v8.0.0

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 2 files included in typeshed's stubs have been modified or renamed: `slugify/__version__.py`, `slugify/slugify.py`.
 - Total lines of Python code added: 3.
 - Total lines of Python code deleted: 3.

## 7.0.0.1 (2022-11-19)

python-slugify: use explicit re-exports (#9225)

Fixes https://github.com/python/typeshed/pull/9224#discussion_r1027053364

## 7.0.0.0 (2022-11-19)

[stubsabot] Bump python-slugify to 7.0.* (#9224)

Release: https://pypi.org/pypi/python-slugify/7.0.0
Homepage: https://github.com/un33k/python-slugify
Diff: https://github.com/un33k/python-slugify/compare/v6.1.2...v7.0.0

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 2 files included in typeshed's stubs have been modified or renamed: `slugify/__init__.py`, `slugify/__version__.py`.
 - Total lines of Python code added: 11.
 - Total lines of Python code deleted: 3.

## 6.1.0.1 (2022-11-18)

Mark `python-slugify` as completed (#9222)

## 6.1.0 (2022-06-29)

[stubsabot] Bump python-slugify to 6.1.* (#8208)

## 5.0.4 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 5.0.2 (2021-10-15)

Use lowercase tuple where possible (#6170)

## 5.0.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 5.0.0 (2021-09-05)

Fix python-slugify replacements argument type (#6004)

Update version field, remove Python 2 compatibility marker

